Learn R Programming

smdata (version 1.3)

euthan: Euthanasia Scale

Description

Euthanasia scale and Christian identification scale data.

Usage

data("euthan")

Arguments

Format

A data frame with 351 observations on the following 3 variables.

mident

a numeric vector measuring the degree to which respondents identify themselves as Christian, on a scale from 0 to 1

teuth

a numeric vector measuring the degree to which respondents favor euthanasia, on a scale from 0 to 1

status

a numeric vector taking the value 0 if the observation is censored and 1 if not

References

Mavor, K. (2004). Religious orientation, social identity and attitudes to homosexuality. Unpublished doctoral dissertation, School of Psychology, The Australian National University, Canberra, A.C.T., Australia.

Examples

Run this code
data("euthan", package="smdata")

Run the code above in your browser using DataLab