Judged probabilities of guilt in a criminal trial scenario (Study 1).
data("guilt1")A data frame with 104 observations on the following 7 variables.
observa numeric vector indexing cases
crguilta numeric vector recording the judged probability of guilt in a criminal trial scenario
cigulta numeric vector recording the judged probability of guilt in a civil trial scenario
crvd1a numeric vector taking the value 1 if the respondent returned a ``guilty'' verdict in the criminal trial and 0 otherwise
crvd2a numeric vector taking the value 1 if the respondent returned a ``not guilty'' verdict in the criminal trial and 0 otherwise
civd1a numeric vector taking the value 1 if the respondent returned a ``guilty'' verdict in the civil trial and 0 otherwise
civd2a numeric vectortaking the value 1 if the respondent returned a ``not guilty'' verdict in the civil trial and 0 otherwise
Smithson,M., Gracik, L., & Deady, S. (2007). Guilty, not guilty, or ?multiple verdict options in jury verdict choices. Journal of Behavioral Decision Making, 20, 481-498.
data("guilt1", package="smdata")
Run the code above in your browser using DataLab